"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Applications = void 0;
const baseResource_1 = require("./baseResource");
class Applications extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/applications", config);
        this.basePath = basePath;
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params === null || params === void 0 ? void 0 : params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params === null || params === void 0 ? void 0 : params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.query) && { "filter[query]": params === null || params === void 0 ? void 0 : params.query }),
            ...((params === null || params === void 0 ? void 0 : params.email) && { "filter[email]": params === null || params === void 0 ? void 0 : params.email }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": this.customStringify(params.tags, ":") }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt"
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async upload(request) {
        let path = `/${request.applicationId}/documents/${request.documentId}`;
        if (request.isBackSide)
            path += "/back";
        let headers = {};
        switch (request.fileType) {
            case "jpeg":
                headers = {
                    "Content-Type": "image/jpeg"
                };
                break;
            case "png":
                headers = {
                    "Content-Type": "image/png"
                };
                break;
            case "pdf":
                headers = {
                    "Content-Type": "application/pdf"
                };
                break;
            default:
                break;
        }
        return this.httpPut(path, request.file, { headers });
    }
    async update(request) {
        return this.httpPatch(`/${request.applicationId}`, { data: request.data });
    }
    async get(applicationId) {
        return this.httpGet(`/${applicationId}`);
    }
    async listDocuments(applicationId) {
        return this.httpGet(`/${applicationId}/documents`);
    }
    async createDocument(applicationId) {
        return this.httpPost(`/${applicationId}/documents`);
    }
    async verifyDocument(request) {
        return this.httpPost(`/${request.applicationId}/documents/${request.documentId}/verify`, { data: request.data });
    }
    async cancel(request) {
        return this.httpPost(`/${request.applicationId}/cancel`, { data: request.data });
    }
    async download(request) {
        let path = `/${request.applicationId}/documents/${request.documentId}/download`;
        if (request.isBackSide)
            path += "/back";
        const responseEncoding = request.responseEncoding || "binary";
        const responseType = request.responseType || "arraybuffer";
        return this.httpGet(path, { responseEncoding, responseType });
    }
    async updateBeneficialOwner(request) {
        return this.httpPatchFullPath(`${this.basePath}/beneficial-owner/${request.beneficialOwnerId}`, { data: request.data });
    }
}
exports.Applications = Applications;
