"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cards = void 0;
const baseResource_1 = require("./baseResource");
class Cards extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/cards", config);
        this.securePath = "https://secure.api.s.unit.sh";
        if (config === null || config === void 0 ? void 0 : config.securePath)
            this.securePath = config.securePath;
    }
    async createDebitCard(request) {
        return await this.httpPost("", { data: request });
    }
    async create(request) {
        return await this.httpPostResourcePath({ data: request });
    }
    async reportStolen(id) {
        const path = `/${id}/report-stolen`;
        return await this.httpPost(path);
    }
    async reportLost(id) {
        return await this.httpPost(`/${id}/report-lost`);
    }
    async closeCard(id) {
        return await this.httpPost(`/${id}/close`);
    }
    async freeze(id) {
        return await this.httpPost(`/${id}/freeze`);
    }
    async unfreeze(id) {
        return await this.httpPost(`/${id}/unfreeze`);
    }
    async replace(request) {
        const data = {
            type: "replaceCard",
            attributes: {
                shippingAddress: request.shippingAddress
            }
        };
        return await this.httpPost(`/${request.id}/replace`, { data });
    }
    /**
     * @param id
     * @param include - Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account. See [Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources).
     */
    async get(id, include = "") {
        return await this.httpGet(`/${id}?include=${include}`);
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.include) && { "include": params.include }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": this.customStringify(params.tags, ":") }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt"
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
    async getPinStatus(id) {
        const path = `/${id}/secure-data/pin/status`;
        return await this.httpGet(path);
    }
    async limits(id) {
        return this.httpGet(`/${id}/limits`);
    }
    async update(request) {
        return await this.httpPatch(`/${request.id}`, request);
    }
    async mobileWalletPayload(request) {
        return await this.httpPostFullPath(`${this.securePath}/cards/${request.cardId}/mobile-wallet-payload`, { data: request.data });
    }
    async enableCardToCardPayments(request) {
        return await this.httpPatch(`/${request.cardId}/enableCardToCardPayment`, { data: request.data });
    }
}
exports.Cards = Cards;
