import { BaseListParams, UnitConfig, UnitResponse } from "../types/common";
import { CreateWebhookRequest, PatchWebhookRequest, Webhook } from "../types/webhooks";
import { BaseResource } from "./baseResource";
export declare class Webhooks extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    create(request: CreateWebhookRequest): Promise<UnitResponse<Webhook>>;
    get(id: string): Promise<UnitResponse<Webhook>>;
    list(params?: WebhookListParams): Promise<UnitResponse<Webhook[]>>;
    update(id: string, request: PatchWebhookRequest): Promise<UnitResponse<Webhook>>;
    enable(id: string): Promise<UnitResponse<Webhook>>;
    disable(id: string): Promise<UnitResponse<Webhook>>;
    verify(signature: string, secret: string, payload: any): boolean;
}
export interface WebhookListParams extends BaseListParams {
    /**
     * Optional. Filters the results that occurred after the specified date. e.g. 2020-01-13T16:01:19.346Z
     * RFC3339 Date string
     */
    since?: string;
    /**
     * Optional. Filters the results that occurred before the specified date. e.g. 2020-01-02T20:06:23.486Z
     * RFC3339 Date string
     */
    until?: string;
    /**
     * Optional. Filters the results that have an id that is higher or equal to the specified id. e.g. 17421
     */
    fromId?: number;
    /**
     * Optional. Filters the results that have an id that is lower or equal to the specified id. e.g. 17432
     */
    toId?: number;
}
