"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractUnitError = exports.UnitError = exports.ApiVersion = void 0;
const axios_1 = __importDefault(require("axios"));
var ApiVersion;
(function (ApiVersion) {
    ApiVersion["V2024_06"] = "V2024_06";
})(ApiVersion = exports.ApiVersion || (exports.ApiVersion = {}));
class UnitError extends Error {
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    constructor(message, underlying, errors) {
        super(message);
        this.isUnitError = true;
        this.name = "UnitError";
        Object.setPrototypeOf(this, new.target.prototype); // restore prototype chain
        this.underlying = underlying;
        this.errors = errors !== null && errors !== void 0 ? errors : [];
    }
}
exports.UnitError = UnitError;
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
const extractUnitError = (underlying) => {
    var _a, _b;
    // for now, we only support extracting a UnitError from an axios error
    if (!underlying || !axios_1.default.isAxiosError(underlying) || !underlying.response) {
        return new UnitError("Unknown Error", underlying);
    }
    let message = `${underlying.response.status} - ${(_a = underlying.response.statusText) !== null && _a !== void 0 ? _a : "Error"}`;
    const errors = (_b = underlying.response.data) === null || _b === void 0 ? void 0 : _b.errors;
    if (!isValidUnitErrorsArray(errors)) {
        return new UnitError(message, underlying);
    }
    if (errors.length === 1) {
        message = `${errors[0].status} - ${errors[0].title}`;
    }
    return new UnitError(message, underlying, errors);
};
exports.extractUnitError = extractUnitError;
const isValidUnitErrorsArray = (errors) => {
    if (errors && Array.isArray(errors)) {
        let isValidErrorsArray = true;
        for (let i = 0; i < errors.length; i++) {
            const error = errors[i];
            if (!error.hasOwnProperty("title") || !error.hasOwnProperty("status")) {
                isValidErrorsArray = false;
                break;
            }
        }
        return isValidErrorsArray;
    }
    return false;
};
